bayespy.inference.vmp.nodes.categorical_markov_chain.CategoricalMarkovChainMoments.compute_dims_from_values
===========================================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical_markov_chain

.. automethod:: CategoricalMarkovChainMoments.compute_dims_from_values